@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2022 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -439,18 +439,18 @@ parse_crawler (char *str, char *match, char *type) {
 
   while (match != str) {
     match--;
-    if (*match == ' ' || *match == '+') {
+    if (*match == ' ' || *match == '+' || match == str) {
       found = 1;
       break;
     }
   }
 
   /* same addr */
-  if (match == str)
+  if (!found && match == str)
     return NULL;
 
   /* account for the previous +|space */
-  if (found)
+  if (found && match != str)
     match++;
 
   if ((ptr = strpbrk (match, "; ")))
@@ -501,6 +501,7 @@ parse_browser (char *match, char *type, int i, char ***hash) {
   char *b = NULL, *ptr = NULL, *slh = NULL;
   size_t cnt = 0, space = 0;
 
+  match = char_replace (match, '+', '-');
   /* Check if there are spaces in the token string, that way strpbrk
    * does not stop at the first space within the token string */
   if ((cnt = count_matches (hash[i][0], ' ')) && (b = match)) {
@@ -552,6 +553,9 @@ verify_browser (char *str, char *type) {
   if (str == NULL || *str == '\0')
     return NULL;
 
+  if ((match = check_http_crawler (str)) && (token = parse_crawler (str, match, type)))
+    return token;
+
   /* check user's list */
   for (i = 0; i < conf.browsers_hash_idx; ++i) {
     if ((match = strstr (str, conf.user_browsers_hash[i][0])) == NULL)
@@ -559,9 +563,6 @@ verify_browser (char *str, char *type) {
     return parse_browser (match, type, i, conf.user_browsers_hash);
   }
 
-  if ((match = check_http_crawler (str)) && (token = parse_crawler (str, match, type)))
-    return token;
-
   /* fallback to default browser list */
   for (j = 0; j < ARRAY_SIZE (browsers); ++j) {
     if ((match = strstr (str, browsers_hash[j][0])) == NULL)
