@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2022 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -210,6 +210,7 @@ cleanup (int ret) {
   if (!conf.output_stdout)
     endwin ();
 
+  fprintf (stderr, "Cleaning up resources...\n");
   /* unable to process valid data */
   if (ret)
     output_logerrors ();
@@ -1394,13 +1395,9 @@ handle_signal_action (GO_UNUSED int sig_number) {
   fprintf (stderr, "\nSIGINT caught!\n");
   fprintf (stderr, "Closing GoAccess...\n");
 
-  stop_ws_server (gwswriter, gwsreader);
+  if (conf.output_stdout && conf.real_time_html)
+    stop_ws_server (gwswriter, gwsreader);
   conf.stop_processing = 1;
-
-  if (!conf.output_stdout) {
-    cleanup (EXIT_SUCCESS);
-    exit (EXIT_SUCCESS);
-  }
 }
 
 static void
@@ -1470,6 +1467,9 @@ initializer (void) {
   parsing_spinner->processed = &(logs->processed);
   parsing_spinner->filename = &(logs->filename);
 
+  /* init reverse lookup thread */
+  gdns_init ();
+
   /* init random number generator */
   srand (getpid ());
   init_pre_storage (logs);
@@ -1619,9 +1619,10 @@ main (int argc, char **argv) {
     goto clean;
   logs->offset = *logs->processed;
 
+  pthread_mutex_lock (&parsing_spinner->mutex);
   parsing_spinner->label = "RENDERING";
-  /* init reverse lookup thread */
-  gdns_init ();
+  pthread_mutex_unlock (&parsing_spinner->mutex);
+
   parse_initial_sort ();
   allocate_holder ();
 
