@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2022 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -711,11 +711,8 @@ read_option_args (int argc, char **argv) {
       conf.ignore_qstr = 1;
       break;
     case 'o':
-      if (!valid_output_type (optarg)) {
-        printf
-          ("[ERROR] Invalid filename extension used, must be any of .csv, .json, or .html\n");
-        exit (EXIT_FAILURE);
-      }
+      if (!valid_output_type (optarg))
+        FATAL ("Invalid filename extension. It must be any of .csv, .json, or .html\n");
       if (conf.output_format_idx < MAX_OUTFORMATS)
         conf.output_formats[conf.output_format_idx++] = optarg;
       break;
