@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2020 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2022 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -329,7 +329,7 @@ decode_url (char *url) {
     decode_hex (decoded, out);
   strip_newlines (out);
 
-  return trim_str (char_replace (out, '+', ' '));
+  return trim_str (out);
 }
 
 /* Process keyphrases from Google search, cache, and translate.
@@ -784,6 +784,11 @@ spec_err (GLogItem * logitem, int code, const char spec, const char *tkn) {
     err = xmalloc (snprintf (NULL, 0, fmt, (tkn ? tkn : "-"), spec) + 1);
     sprintf (err, fmt, (tkn ? tkn : "-"), spec);
     break;
+  case SPEC_LINE_INV:
+    fmt = "Incompatible format due to early parsed line ending '\\0'.";
+    err = xmalloc (snprintf (NULL, 0, fmt, (tkn ? tkn : "-")) + 1);
+    sprintf (err, fmt, (tkn ? tkn : "-"));
+    break;
   }
   logitem->errstr = err;
 
@@ -1103,8 +1108,7 @@ parse_specifier (GLogItem * logitem, char **str, const char *p, const char *end)
 
     tkn = parse_string (&(*str), end, 1);
     if (tkn != NULL && *tkn != '\0') {
-      /* Make sure the user agent is decoded (i.e.: CloudFront)
-       * and replace all '+' with ' ' (i.e.: w3c) */
+      /* Make sure the user agent is decoded (i.e.: CloudFront) */
       logitem->agent = decode_url (tkn);
       set_agent_hash (logitem);
       free (tkn);
@@ -1370,6 +1374,8 @@ parse_format (GLogItem * logitem, char *str, char *lfmt) {
       tilde++;
       continue;
     }
+    if (*str == '\0')
+      return spec_err (logitem, SPEC_LINE_INV, '-', NULL);
     if (*str == '\n')
       return 0;
 
